# Batch-Ai-App

Below packages will be imported from the model container for generating the mode explanations,
```


```

Below packages are installed at the run time
```
pip install bs4==0.0.1 -t "/packages/custom_plugin/xai";
```